<?php

/***************************************************************************
 *
 * Copyright (c) by Andreas Unterkircher, unki@netshadow.at
 * All rights reserved
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 ***************************************************************************/

require_once "phpfspot.class.php";

class PHPFSPOT_IMG {
   
   var $db;
   var $parent;

   /**
    * PHPFSPOT_IMG class constructor
    */
   public function __construct()
   {
      $this->parent = new PHPFSPOT;
      $this->db = $this->parent->db;

   } // __construct()

   /**
    * PHPFSPOT_IMG class destructor
    */
   public function __destruct()
   {

   } // __desctruct()

   /**
    * sends the specified image to the browser
    *
    * this function will send the specified image to 
    * the client - in the specified width. it also try's
    * to create on-the-fly missing thumbnails via PHPFSPOT
    * gen_thumbs function.
    */
   public function show($idx, $width = 0)
   {
      if($idx == 'rand')
         $idx = $this->parent->get_random_photo();

      $details = $this->parent->get_photo_details($idx);
   
      if(!$details) {
         $this->parent->showTextImage("The image (". $idx .") you requested is unknown");
         return;
      }

      /* no width specified - show photo in its original size */
      if($width == 0) {
         $fullpath = $this->parent->translate_path($this->parent->parse_uri($details['uri'], 'fullpath'));
      }
      /* show thumbnail */
      else {
         /* if no entry for this photo is yet in the database, create thumb */
         if(!$this->parent->getMD5($idx)) {
            $this->parent->gen_thumb($idx);
         }
         $fullpath = $this->parent->get_thumb_path($width, $idx);
         /* if the thumb file does not exist, create it */
         if(!file_exists($fullpath)) {
            $this->parent->gen_thumb($idx);
         }
      }

      if(!file_exists($fullpath)) {
         $this->parent->showTextImage("File ". basename($fullpath) ." does not exist");
         return;
      }
      if(!is_readable($fullpath)) {
         $this->parent->showTextImage("File ". basename($fullpath) ." is not readable. Check the permissions");
         return;
      }

      $tmp = getimagesize($fullpath);
      $mime = $tmp['mime'];

      if(!$this->parent->checkifImageSupported($mime)) {
         $this->parent->showTextImage("Unsupported Image Type");
         return;
      }

      Header("Content-Type: ". $mime);
      Header("Content-Length: ". filesize($fullpath));
      Header("Content-Transfer-Encoding: binary\n");
      Header("Content-Disposition: inline; filename=\"". $this->parent->parse_uri($details['uri'], 'filename') ."\"");
      Header("Content-Description: ". $this->parent->parse_uri($details['uri'], 'filename'));
      Header("Accept-Ranges: bytes");
      Header("Connection: close");
      Header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
      Header("Cache-Control: no-cache");
      Header("Pragma: no-cache");
         
      $file = fopen($fullpath, "rb");
      fpassthru($file);
      @fclose($file);

   } // show()

}

if(isset($_GET['idx']) && (is_numeric($_GET['idx']) || $_GET['idx'] == 'rand')) {

   $img = new PHPFSPOT_IMG;

   if(isset($_GET['width']) && is_numeric($_GET['width'])) 
      $img->show($_GET['idx'], $_GET['width']);
   else
      $img->show($_GET['idx']);
}

?>
